pub fn dispatch_elementwise_generic<T>(
a: &Array<T>,
b: &Array<T>,
kind: ElementwiseKind,
) -> Result<Array<T>>where
T: DTypeValue,Expand description
Dispatch genérico para operaciones elementwise que mantiene el tipo nativo
Esta función hace dispatch basado en el tipo T en runtime, llamando al
kernel apropiado y manteniendo los datos en su tipo nativo (Vec
NOTA: Devuelve Array